package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.uc.api.dto.DictItemDTO;
import com.chelvc.cloud.uc.api.param.DictEntryModifyParam;
import com.chelvc.cloud.uc.api.param.DictItemModifyParam;
import com.chelvc.cloud.uc.api.service.DictItemService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import java.util.List;

/**
 * @author valley
 * @date 2024/01/17 00:01
 **/
@Validated
@RestController
@ResponseWrapping
@PreAuthorize("isScope('EMPLOYEE')")
public class DictItemController {

    @DubboReference
    DictItemService dictItemService;

    @PostMapping("dict/item/add")
    public Long addDictItem(@RequestBody @Valid DictItemModifyParam param) {
        return this.dictItemService.addDictItem(param);
    }

    @GetMapping("dict/item/{entryId}")
    public List<DictItemDTO> getDictItem(@PathVariable @Min(value = 1,message = "entryId不能小于1") Long entryId) {
        return this.dictItemService.getDictItem(entryId);
    }

    @PutMapping("dict/item/update/{id}")
    public void updateDictEntry(@PathVariable("id") @Min(value = 1, message = "id不能小于1") Long id, @RequestBody @Valid DictItemModifyParam param) {
        this.dictItemService.updateDictItem(id, param);
    }


    @PostMapping("dict/item/remove/{id}")
    public void removeDictItem(@PathVariable @Min(value = 1, message = "id不能小于1") Long id) {
         this.dictItemService.removeDictItem(id);
    }

}
